/*
 * Autogenerated by the Meson build system.
 * Do not edit, your changes will be lost.
 */

#pragma once

#define CYSIGNALS_CXX_ATOMIC 0

#define CYSIGNALS_CXX_ATOMIC_WITH_OPENMP 0

#define CYSIGNALS_C_ATOMIC 1

#define CYSIGNALS_C_ATOMIC_WITH_OPENMP 1

#define CYSIGNALS_STD_ATOMIC 1

#define CYSIGNALS_STD_ATOMIC_WITH_OPENMP 1

#define CYSIGNALS_USE_SIGSETJMP 1

#define ENABLE_DEBUG_CYSIGNALS 0

#define HAVE_BACKTRACE 1

#define HAVE_EMMS 0

#define HAVE_EXECINFO_H 1

#define HAVE_FORK 1

#define HAVE_KILL 1

#define HAVE_SIGALTSTACK 1

#define HAVE_SIGPROCMASK 1

#define HAVE_SYS_MMAN_H 1

#define HAVE_SYS_PRCTL_H 1

#define HAVE_SYS_WAIT_H 1

#define HAVE_TIME_H 1

#define HAVE_WINDOWS_H 0

